# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TimeProofRequestConfig(_message.Message):
    __slots__ = ("initialRetryDelay", "maxRetryDelay", "maxSequencingDelay")
    INITIALRETRYDELAY_FIELD_NUMBER: _ClassVar[int]
    MAXRETRYDELAY_FIELD_NUMBER: _ClassVar[int]
    MAXSEQUENCINGDELAY_FIELD_NUMBER: _ClassVar[int]
    initialRetryDelay: _duration_pb2.Duration
    maxRetryDelay: _duration_pb2.Duration
    maxSequencingDelay: _duration_pb2.Duration
    def __init__(self, initialRetryDelay: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., maxRetryDelay: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., maxSequencingDelay: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class DomainTimeTrackerConfig(_message.Message):
    __slots__ = ("observationLatency", "patienceDuration", "minObservationDuration", "timeProofRequest")
    OBSERVATIONLATENCY_FIELD_NUMBER: _ClassVar[int]
    PATIENCEDURATION_FIELD_NUMBER: _ClassVar[int]
    MINOBSERVATIONDURATION_FIELD_NUMBER: _ClassVar[int]
    TIMEPROOFREQUEST_FIELD_NUMBER: _ClassVar[int]
    observationLatency: _duration_pb2.Duration
    patienceDuration: _duration_pb2.Duration
    minObservationDuration: _duration_pb2.Duration
    timeProofRequest: TimeProofRequestConfig
    def __init__(self, observationLatency: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., patienceDuration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., minObservationDuration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., timeProofRequest: _Optional[_Union[TimeProofRequestConfig, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HashAlgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingHashAlgorithm: _ClassVar[HashAlgorithm]
    Sha256: _ClassVar[HashAlgorithm]

class HmacAlgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingHmacAlgorithm: _ClassVar[HmacAlgorithm]
    HmacSha256: _ClassVar[HmacAlgorithm]

class SignatureFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingSignatureFormat: _ClassVar[SignatureFormat]
    RawSignatureFormat: _ClassVar[SignatureFormat]

class KeyPurpose(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UnknownKeyPurpose: _ClassVar[KeyPurpose]
    SigningKeyPurpose: _ClassVar[KeyPurpose]
    EncryptionKeyPurpose: _ClassVar[KeyPurpose]

class SigningKeyScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingSigningKeyScheme: _ClassVar[SigningKeyScheme]
    Ed25519: _ClassVar[SigningKeyScheme]
    EcDsaP256: _ClassVar[SigningKeyScheme]
    EcDsaP384: _ClassVar[SigningKeyScheme]
    Sm2: _ClassVar[SigningKeyScheme]

class EncryptionKeyScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingEncryptionKeyScheme: _ClassVar[EncryptionKeyScheme]
    EciesP256HkdfHmacSha256Aes128Gcm: _ClassVar[EncryptionKeyScheme]
    EciesP256HmacSha256Aes128Cbc: _ClassVar[EncryptionKeyScheme]
    Rsa2048OaepSha256: _ClassVar[EncryptionKeyScheme]

class SymmetricKeyScheme(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingSymmetricKeyScheme: _ClassVar[SymmetricKeyScheme]
    Aes128Gcm: _ClassVar[SymmetricKeyScheme]

class CryptoKeyFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingCryptoKeyFormat: _ClassVar[CryptoKeyFormat]
    Tink: _ClassVar[CryptoKeyFormat]
    Der: _ClassVar[CryptoKeyFormat]
    Raw: _ClassVar[CryptoKeyFormat]
    Symbolic: _ClassVar[CryptoKeyFormat]
MissingHashAlgorithm: HashAlgorithm
Sha256: HashAlgorithm
MissingHmacAlgorithm: HmacAlgorithm
HmacSha256: HmacAlgorithm
MissingSignatureFormat: SignatureFormat
RawSignatureFormat: SignatureFormat
UnknownKeyPurpose: KeyPurpose
SigningKeyPurpose: KeyPurpose
EncryptionKeyPurpose: KeyPurpose
MissingSigningKeyScheme: SigningKeyScheme
Ed25519: SigningKeyScheme
EcDsaP256: SigningKeyScheme
EcDsaP384: SigningKeyScheme
Sm2: SigningKeyScheme
MissingEncryptionKeyScheme: EncryptionKeyScheme
EciesP256HkdfHmacSha256Aes128Gcm: EncryptionKeyScheme
EciesP256HmacSha256Aes128Cbc: EncryptionKeyScheme
Rsa2048OaepSha256: EncryptionKeyScheme
MissingSymmetricKeyScheme: SymmetricKeyScheme
Aes128Gcm: SymmetricKeyScheme
MissingCryptoKeyFormat: CryptoKeyFormat
Tink: CryptoKeyFormat
Der: CryptoKeyFormat
Raw: CryptoKeyFormat
Symbolic: CryptoKeyFormat

class Hmac(_message.Message):
    __slots__ = ("algorithm", "hmac")
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    HMAC_FIELD_NUMBER: _ClassVar[int]
    algorithm: HmacAlgorithm
    hmac: bytes
    def __init__(self, algorithm: _Optional[_Union[HmacAlgorithm, str]] = ..., hmac: _Optional[bytes] = ...) -> None: ...

class Salt(_message.Message):
    __slots__ = ("hmac", "salt")
    HMAC_FIELD_NUMBER: _ClassVar[int]
    SALT_FIELD_NUMBER: _ClassVar[int]
    hmac: HmacAlgorithm
    salt: bytes
    def __init__(self, hmac: _Optional[_Union[HmacAlgorithm, str]] = ..., salt: _Optional[bytes] = ...) -> None: ...

class Signature(_message.Message):
    __slots__ = ("format", "signature", "signed_by")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FIELD_NUMBER: _ClassVar[int]
    format: SignatureFormat
    signature: bytes
    signed_by: str
    def __init__(self, format: _Optional[_Union[SignatureFormat, str]] = ..., signature: _Optional[bytes] = ..., signed_by: _Optional[str] = ...) -> None: ...

class PublicKey(_message.Message):
    __slots__ = ("signing_public_key", "encryption_public_key")
    SIGNING_PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    signing_public_key: SigningPublicKey
    encryption_public_key: EncryptionPublicKey
    def __init__(self, signing_public_key: _Optional[_Union[SigningPublicKey, _Mapping]] = ..., encryption_public_key: _Optional[_Union[EncryptionPublicKey, _Mapping]] = ...) -> None: ...

class PublicKeyWithName(_message.Message):
    __slots__ = ("public_key", "name")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    public_key: PublicKey
    name: str
    def __init__(self, public_key: _Optional[_Union[PublicKey, _Mapping]] = ..., name: _Optional[str] = ...) -> None: ...

class PrivateKey(_message.Message):
    __slots__ = ("signing_private_key", "encryption_private_key")
    SIGNING_PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    signing_private_key: SigningPrivateKey
    encryption_private_key: EncryptionPrivateKey
    def __init__(self, signing_private_key: _Optional[_Union[SigningPrivateKey, _Mapping]] = ..., encryption_private_key: _Optional[_Union[EncryptionPrivateKey, _Mapping]] = ...) -> None: ...

class SigningPublicKey(_message.Message):
    __slots__ = ("id", "format", "public_key", "scheme")
    ID_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    id: str
    format: CryptoKeyFormat
    public_key: bytes
    scheme: SigningKeyScheme
    def __init__(self, id: _Optional[str] = ..., format: _Optional[_Union[CryptoKeyFormat, str]] = ..., public_key: _Optional[bytes] = ..., scheme: _Optional[_Union[SigningKeyScheme, str]] = ...) -> None: ...

class SigningPrivateKey(_message.Message):
    __slots__ = ("id", "format", "private_key", "scheme")
    ID_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    id: str
    format: CryptoKeyFormat
    private_key: bytes
    scheme: SigningKeyScheme
    def __init__(self, id: _Optional[str] = ..., format: _Optional[_Union[CryptoKeyFormat, str]] = ..., private_key: _Optional[bytes] = ..., scheme: _Optional[_Union[SigningKeyScheme, str]] = ...) -> None: ...

class SigningKeyPair(_message.Message):
    __slots__ = ("public_key", "private_key")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: SigningPublicKey
    private_key: SigningPrivateKey
    def __init__(self, public_key: _Optional[_Union[SigningPublicKey, _Mapping]] = ..., private_key: _Optional[_Union[SigningPrivateKey, _Mapping]] = ...) -> None: ...

class EncryptionPublicKey(_message.Message):
    __slots__ = ("id", "format", "public_key", "scheme")
    ID_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    id: str
    format: CryptoKeyFormat
    public_key: bytes
    scheme: EncryptionKeyScheme
    def __init__(self, id: _Optional[str] = ..., format: _Optional[_Union[CryptoKeyFormat, str]] = ..., public_key: _Optional[bytes] = ..., scheme: _Optional[_Union[EncryptionKeyScheme, str]] = ...) -> None: ...

class EncryptionPrivateKey(_message.Message):
    __slots__ = ("id", "format", "private_key", "scheme")
    ID_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    id: str
    format: CryptoKeyFormat
    private_key: bytes
    scheme: EncryptionKeyScheme
    def __init__(self, id: _Optional[str] = ..., format: _Optional[_Union[CryptoKeyFormat, str]] = ..., private_key: _Optional[bytes] = ..., scheme: _Optional[_Union[EncryptionKeyScheme, str]] = ...) -> None: ...

class EncryptionKeyPair(_message.Message):
    __slots__ = ("public_key", "private_key")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: EncryptionPublicKey
    private_key: EncryptionPrivateKey
    def __init__(self, public_key: _Optional[_Union[EncryptionPublicKey, _Mapping]] = ..., private_key: _Optional[_Union[EncryptionPrivateKey, _Mapping]] = ...) -> None: ...

class CryptoKeyPair(_message.Message):
    __slots__ = ("signing_key_pair", "encryption_key_pair")
    SIGNING_KEY_PAIR_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_KEY_PAIR_FIELD_NUMBER: _ClassVar[int]
    signing_key_pair: SigningKeyPair
    encryption_key_pair: EncryptionKeyPair
    def __init__(self, signing_key_pair: _Optional[_Union[SigningKeyPair, _Mapping]] = ..., encryption_key_pair: _Optional[_Union[EncryptionKeyPair, _Mapping]] = ...) -> None: ...

class SymmetricKey(_message.Message):
    __slots__ = ("format", "key", "scheme")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    SCHEME_FIELD_NUMBER: _ClassVar[int]
    format: CryptoKeyFormat
    key: bytes
    scheme: SymmetricKeyScheme
    def __init__(self, format: _Optional[_Union[CryptoKeyFormat, str]] = ..., key: _Optional[bytes] = ..., scheme: _Optional[_Union[SymmetricKeyScheme, str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import sys
from typing import Any, Collection, NewType, Sequence, Union, overload

from .basic import to_str

if sys.version_info >= (3, 11):
    from typing import TypeAlias
else:
    from typing_extensions import TypeAlias

__all__ = ["Party", "Parties", "to_party", "to_parties"]

Party = NewType("Party", str)
Parties: TypeAlias = Union[Party, Collection[Party]]


def to_party(o: Any, /) -> Party:
    return Party(to_str(o))


@overload
def to_parties(o: None, /) -> None: ...


@overload
def to_parties(o: Union[str, Collection[str], Parties], /) -> Sequence[Party]: ...


def to_parties(o: Union[None, str, Collection[str], Parties], /) -> Union[None, Sequence[Party]]:
    """
    Return the specified object as a collection of parties.

    :param o:
        The object to convert to a set of parties.
    """
    if o is None:
        return None
    elif isinstance(o, str):
        return (Party(o),)
    else:
        return tuple(Party(p) for p in o)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .participant_repair_service_pb2 import AcsSnapshotChunk, DownloadRequest, ExportAcsRequest, ExportAcsResponse, IgnoreEventsRequest, IgnoreEventsResponse, ImportAcsRequest, ImportAcsResponse, MigrateDomainRequest, MigrateDomainResponse, PurgeContractsRequest, PurgeContractsResponse, PurgeDeactivatedDomainRequest, PurgeDeactivatedDomainResponse, UnignoreEventsRequest, UnignoreEventsResponse, UploadRequest, UploadResponse

__all__ = [
    "ParticipantRepairServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class ParticipantRepairServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _ParticipantRepairServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _ParticipantRepairServiceAsyncStub: ...  # type: ignore
    def Download(self, __1: DownloadRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[AcsSnapshotChunk], _grpc_aio.UnaryStreamCall[_typing.Any, AcsSnapshotChunk]]: ...
    def ExportAcs(self, __1: ExportAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[ExportAcsResponse], _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsResponse]]: ...
    def Upload(self, __1: _typing.Iterable[UploadRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[UploadResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, UploadResponse]]: ...
    def ImportAcs(self, __1: _typing.Iterable[ImportAcsRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ImportAcsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ImportAcsResponse]]: ...
    def PurgeContracts(self, __1: PurgeContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[PurgeContractsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, PurgeContractsResponse]]: ...
    def MigrateDomain(self, __1: MigrateDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[MigrateDomainResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, MigrateDomainResponse]]: ...
    def PurgeDeactivatedDomain(self, __1: PurgeDeactivatedDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[PurgeDeactivatedDomainResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, PurgeDeactivatedDomainResponse]]: ...
    def IgnoreEvents(self, __1: IgnoreEventsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[IgnoreEventsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, IgnoreEventsResponse]]: ...
    def UnignoreEvents(self, __1: UnignoreEventsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[UnignoreEventsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, UnignoreEventsResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _ParticipantRepairServiceBlockingStub(ParticipantRepairServiceStub):
    def Download(self, __1: DownloadRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[AcsSnapshotChunk]: ...
    def ExportAcs(self, __1: ExportAcsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportAcsResponse]: ...
    def Upload(self, __1: _typing.Iterable[UploadRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UploadResponse: ...
    def ImportAcs(self, __1: _typing.Iterable[ImportAcsRequest], timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportAcsResponse: ...
    def PurgeContracts(self, __1: PurgeContractsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PurgeContractsResponse: ...
    def MigrateDomain(self, __1: MigrateDomainRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> MigrateDomainResponse: ...
    def PurgeDeactivatedDomain(self, __1: PurgeDeactivatedDomainRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PurgeDeactivatedDomainResponse: ...
    def IgnoreEvents(self, __1: IgnoreEventsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> IgnoreEventsResponse: ...
    def UnignoreEvents(self, __1: UnignoreEventsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> UnignoreEventsResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _ParticipantRepairServiceAsyncStub(ParticipantRepairServiceStub):
    def Download(self, __1: DownloadRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, AcsSnapshotChunk]: ...  # type: ignore
    def ExportAcs(self, __1: ExportAcsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportAcsResponse]: ...  # type: ignore
    def Upload(self, __1: _typing.Iterable[UploadRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, UploadResponse]: ...  # type: ignore
    def ImportAcs(self, __1: _typing.Iterable[ImportAcsRequest], *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportAcsResponse]: ...  # type: ignore
    def PurgeContracts(self, __1: PurgeContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PurgeContractsResponse]: ...  # type: ignore
    def MigrateDomain(self, __1: MigrateDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, MigrateDomainResponse]: ...  # type: ignore
    def PurgeDeactivatedDomain(self, __1: PurgeDeactivatedDomainRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, PurgeDeactivatedDomainResponse]: ...  # type: ignore
    def IgnoreEvents(self, __1: IgnoreEventsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, IgnoreEventsResponse]: ...  # type: ignore
    def UnignoreEvents(self, __1: UnignoreEventsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, UnignoreEventsResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
This module contains the Python API for interacting with the Ledger API.
"""
from __future__ import annotations

__all__ = [
    "connect",
    "Command",
    "Connection",
    "ContractData",
    "ContractId",
    "CreateAndExerciseCommand",
    "CreateCommand",
    "DazlError",
    "ExerciseByKeyCommand",
    "ExerciseCommand",
    "LOG",
    "Party",
    "__version__",
    "frozendict",
]

from ._logging import LOG
from .ledger import (
    Command,
    Connection,
    CreateAndExerciseCommand,
    CreateCommand,
    ExerciseByKeyCommand,
    ExerciseCommand,
    connect,
)
from .prim import ContractData, ContractId, DazlError, FrozenDict as frozendict, Party

# Large Protobuf message support

# These methods are undocumented, but is required to read even moderately sized DALF's.
try:
    # For Protobuf libraries version 4 or later (using upb)
    # noinspection PyPackageRequirements,PyUnresolvedReferences,PyProtectedMember
    from google._upb._message import SetAllowOversizeProtos

    SetAllowOversizeProtos(True)
except ImportError:
    pass

try:
    # For Protobuf libraries version 3 or earlier (using upb)
    # noinspection PyPackageRequirements,PyUnresolvedReferences,PyProtectedMember
    from google.protobuf.pyext import _message

    _message.SetAllowOversizeProtos(True)
except ImportError:
    pass


__version__ = "8.3.0"



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/event.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"com/daml/ledger/api/v2/event.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\"com/daml/ledger/api/v2/value.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"\x97\x01\n\x05\x45vent\x12@\n\x07\x63reated\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v2.CreatedEventH\x00R\x07\x63reated\x12\x43\n\x08\x61rchived\x18\x02 \x01(\x0b\x32%.com.daml.ledger.api.v2.ArchivedEventH\x00R\x08\x61rchivedB\x07\n\x05\x65vent\"\xe1\x04\n\x0c\x43reatedEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12@\n\x0c\x63ontract_key\x18\x04 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0b\x63ontractKey\x12I\n\x10\x63reate_arguments\x18\x05 \x01(\x0b\x32\x1e.com.daml.ledger.api.v2.RecordR\x0f\x63reateArguments\x12,\n\x12\x63reated_event_blob\x18\x06 \x01(\x0cR\x10\x63reatedEventBlob\x12N\n\x0finterface_views\x18\x07 \x03(\x0b\x32%.com.daml.ledger.api.v2.InterfaceViewR\x0einterfaceViews\x12\'\n\x0fwitness_parties\x18\x08 \x03(\tR\x0ewitnessParties\x12 \n\x0bsignatories\x18\t \x03(\tR\x0bsignatories\x12\x1c\n\tobservers\x18\n \x03(\tR\tobservers\x12\x39\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12!\n\x0cpackage_name\x18\x0c \x01(\tR\x0bpackageName\"\xca\x01\n\rInterfaceView\x12\x45\n\x0cinterface_id\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x33\n\x0bview_status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusR\nviewStatus\x12=\n\nview_value\x18\x03 \x01(\x0b\x32\x1e.com.daml.ledger.api.v2.RecordR\tviewValue\"\xdc\x01\n\rArchivedEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\'\n\x0fwitness_parties\x18\x04 \x03(\tR\x0ewitnessParties\x12!\n\x0cpackage_name\x18\x05 \x01(\tR\x0bpackageName\"\xb9\x04\n\x0e\x45xercisedEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12\x43\n\x0btemplate_id\x18\x03 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x45\n\x0cinterface_id\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x16\n\x06\x63hoice\x18\x05 \x01(\tR\x06\x63hoice\x12\x46\n\x0f\x63hoice_argument\x18\x06 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x63hoiceArgument\x12%\n\x0e\x61\x63ting_parties\x18\x07 \x03(\tR\ractingParties\x12\x1c\n\tconsuming\x18\x08 \x01(\x08R\tconsuming\x12\'\n\x0fwitness_parties\x18\t \x03(\tR\x0ewitnessParties\x12&\n\x0f\x63hild_event_ids\x18\n \x03(\tR\rchildEventIds\x12\x46\n\x0f\x65xercise_result\x18\x0b \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x65xerciseResult\x12!\n\x0cpackage_name\x18\x0c \x01(\tR\x0bpackageNameB\x89\x01\n\x16\x63om.daml.ledger.api.v2B\x0f\x45ventOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\017EventOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_EVENT']._serialized_start=157
  _globals['_EVENT']._serialized_end=308
  _globals['_CREATEDEVENT']._serialized_start=311
  _globals['_CREATEDEVENT']._serialized_end=920
  _globals['_INTERFACEVIEW']._serialized_start=923
  _globals['_INTERFACEVIEW']._serialized_end=1125
  _globals['_ARCHIVEDEVENT']._serialized_start=1128
  _globals['_ARCHIVEDEVENT']._serialized_end=1348
  _globals['_EXERCISEDEVENT']._serialized_start=1351
  _globals['_EXERCISEDEVENT']._serialized_end=1920
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/crypto/admin/v30/vault_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/crypto/admin/v30/vault_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<com/digitalasset/canton/crypto/admin/v30/vault_service.proto\x12(com.digitalasset.canton.crypto.admin.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\"\xdd\x01\n\x1aGenerateCertificateRequest\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12\'\n\x0f\x63\x65rtificate_key\x18\x02 \x01(\tR\x0e\x63\x65rtificateKey\x12-\n\x12\x61\x64\x64itional_subject\x18\x03 \x01(\tR\x11\x61\x64\x64itionalSubject\x12:\n\x19subject_alternative_names\x18\x04 \x03(\tR\x17subjectAlternativeNames\":\n\x1bGenerateCertificateResponse\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"7\n\x16ListCertificateRequest\x12\x1d\n\nfilter_uid\x18\x01 \x01(\tR\tfilterUid\"\xa4\x01\n\x17ListCertificateResponse\x12\x62\n\x07results\x18\x01 \x03(\x0b\x32H.com.digitalasset.canton.crypto.admin.v30.ListCertificateResponse.ResultR\x07results\x1a%\n\x06Result\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"7\n\x18ImportCertificateRequest\x12\x1b\n\tx509_cert\x18\x01 \x01(\tR\x08x509Cert\"B\n\x19ImportCertificateResponse\x12%\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tR\rcertificateId\"K\n\x16ImportPublicKeyRequest\x12\x1d\n\npublic_key\x18\x01 \x01(\x0cR\tpublicKey\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\";\n\x17ImportPublicKeyResponse\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\"\x91\x01\n\x0fListKeysFilters\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12H\n\x07purpose\x18\x03 \x03(\x0e\x32..com.digitalasset.canton.crypto.v30.KeyPurposeR\x07purpose\"h\n\x11ListMyKeysRequest\x12S\n\x07\x66ilters\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.crypto.admin.v30.ListKeysFiltersR\x07\x66ilters\"l\n\x15ListPublicKeysRequest\x12S\n\x07\x66ilters\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.crypto.admin.v30.ListKeysFiltersR\x07\x66ilters\"\xa2\x01\n\x12PrivateKeyMetadata\x12\x66\n\x14public_key_with_name\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.PublicKeyWithNameR\x11publicKeyWithName\x12$\n\x0ewrapper_key_id\x18\x02 \x01(\tR\x0cwrapperKeyId\"\x86\x01\n\x12ListMyKeysResponse\x12p\n\x15private_keys_metadata\x18\x01 \x03(\x0b\x32<.com.digitalasset.canton.crypto.admin.v30.PrivateKeyMetadataR\x13privateKeysMetadata\"p\n\x16ListPublicKeysResponse\x12V\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.PublicKeyWithNameR\npublicKeys\"\x84\x01\n\x19GenerateSigningKeyRequest\x12S\n\nkey_scheme\x18\x01 \x01(\x0e\x32\x34.com.digitalasset.canton.crypto.v30.SigningKeySchemeR\tkeyScheme\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"q\n\x1aGenerateSigningKeyResponse\x12S\n\npublic_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\tpublicKey\"\x84\x01\n\x1cGenerateEncryptionKeyRequest\x12P\n\x08key_spec\x18\x01 \x01(\x0e\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeySpecR\x07keySpec\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"w\n\x1dGenerateEncryptionKeyResponse\x12V\n\npublic_key\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyR\tpublicKey\"P\n\x1cRegisterKmsSigningKeyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"t\n\x1dRegisterKmsSigningKeyResponse\x12S\n\npublic_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\tpublicKey\"S\n\x1fRegisterKmsEncryptionKeyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"z\n RegisterKmsEncryptionKeyResponse\x12V\n\npublic_key\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyR\tpublicKey\"F\n\x17RotateWrapperKeyRequest\x12+\n\x12new_wrapper_key_id\x18\x01 \x01(\tR\x0fnewWrapperKeyId\"\x1a\n\x18RotateWrapperKeyResponse\"\x18\n\x16GetWrapperKeyIdRequest\"?\n\x17GetWrapperKeyIdResponse\x12$\n\x0ewrapper_key_id\x18\x01 \x01(\tR\x0cwrapperKeyId\"\x7f\n\x14\x45xportKeyPairRequest\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\x12)\n\x10protocol_version\x18\x02 \x01(\x05R\x0fprotocolVersion\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"2\n\x15\x45xportKeyPairResponse\x12\x19\n\x08key_pair\x18\x01 \x01(\x0cR\x07keyPair\"a\n\x14ImportKeyPairRequest\x12\x19\n\x08key_pair\x18\x01 \x01(\x0cR\x07keyPair\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"\x17\n\x15ImportKeyPairResponse\"8\n\x14\x44\x65leteKeyPairRequest\x12 \n\x0b\x66ingerprint\x18\x01 \x01(\tR\x0b\x66ingerprint\"\x17\n\x15\x44\x65leteKeyPairResponse2\xe1\x0e\n\x0cVaultService\x12\x87\x01\n\nListMyKeys\x12;.com.digitalasset.canton.crypto.admin.v30.ListMyKeysRequest\x1a<.com.digitalasset.canton.crypto.admin.v30.ListMyKeysResponse\x12\x9f\x01\n\x12GenerateSigningKey\x12\x43.com.digitalasset.canton.crypto.admin.v30.GenerateSigningKeyRequest\x1a\x44.com.digitalasset.canton.crypto.admin.v30.GenerateSigningKeyResponse\x12\xa8\x01\n\x15GenerateEncryptionKey\x12\x46.com.digitalasset.canton.crypto.admin.v30.GenerateEncryptionKeyRequest\x1aG.com.digitalasset.canton.crypto.admin.v30.GenerateEncryptionKeyResponse\x12\xb1\x01\n\x18RegisterKmsEncryptionKey\x12I.com.digitalasset.canton.crypto.admin.v30.RegisterKmsEncryptionKeyRequest\x1aJ.com.digitalasset.canton.crypto.admin.v30.RegisterKmsEncryptionKeyResponse\x12\xa8\x01\n\x15RegisterKmsSigningKey\x12\x46.com.digitalasset.canton.crypto.admin.v30.RegisterKmsSigningKeyRequest\x1aG.com.digitalasset.canton.crypto.admin.v30.RegisterKmsSigningKeyResponse\x12\x96\x01\n\x0fImportPublicKey\x12@.com.digitalasset.canton.crypto.admin.v30.ImportPublicKeyRequest\x1a\x41.com.digitalasset.canton.crypto.admin.v30.ImportPublicKeyResponse\x12\x93\x01\n\x0eListPublicKeys\x12?.com.digitalasset.canton.crypto.admin.v30.ListPublicKeysRequest\x1a@.com.digitalasset.canton.crypto.admin.v30.ListPublicKeysResponse\x12\x99\x01\n\x10RotateWrapperKey\x12\x41.com.digitalasset.canton.crypto.admin.v30.RotateWrapperKeyRequest\x1a\x42.com.digitalasset.canton.crypto.admin.v30.RotateWrapperKeyResponse\x12\x96\x01\n\x0fGetWrapperKeyId\x12@.com.digitalasset.canton.crypto.admin.v30.GetWrapperKeyIdRequest\x1a\x41.com.digitalasset.canton.crypto.admin.v30.GetWrapperKeyIdResponse\x12\x90\x01\n\rExportKeyPair\x12>.com.digitalasset.canton.crypto.admin.v30.ExportKeyPairRequest\x1a?.com.digitalasset.canton.crypto.admin.v30.ExportKeyPairResponse\x12\x90\x01\n\rImportKeyPair\x12>.com.digitalasset.canton.crypto.admin.v30.ImportKeyPairRequest\x1a?.com.digitalasset.canton.crypto.admin.v30.ImportKeyPairResponse\x12\x90\x01\n\rDeleteKeyPair\x12>.com.digitalasset.canton.crypto.admin.v30.DeleteKeyPairRequest\x1a?.com.digitalasset.canton.crypto.admin.v30.DeleteKeyPairResponseBYZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.crypto.admin.v30.vault_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZWgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/admin/v30'
  _globals['_GENERATECERTIFICATEREQUEST']._serialized_start=156
  _globals['_GENERATECERTIFICATEREQUEST']._serialized_end=377
  _globals['_GENERATECERTIFICATERESPONSE']._serialized_start=379
  _globals['_GENERATECERTIFICATERESPONSE']._serialized_end=437
  _globals['_LISTCERTIFICATEREQUEST']._serialized_start=439
  _globals['_LISTCERTIFICATEREQUEST']._serialized_end=494
  _globals['_LISTCERTIFICATERESPONSE']._serialized_start=497
  _globals['_LISTCERTIFICATERESPONSE']._serialized_end=661
  _globals['_LISTCERTIFICATERESPONSE_RESULT']._serialized_start=624
  _globals['_LISTCERTIFICATERESPONSE_RESULT']._serialized_end=661
  _globals['_IMPORTCERTIFICATEREQUEST']._serialized_start=663
  _globals['_IMPORTCERTIFICATEREQUEST']._serialized_end=718
  _globals['_IMPORTCERTIFICATERESPONSE']._serialized_start=720
  _globals['_IMPORTCERTIFICATERESPONSE']._serialized_end=786
  _globals['_IMPORTPUBLICKEYREQUEST']._serialized_start=788
  _globals['_IMPORTPUBLICKEYREQUEST']._serialized_end=863
  _globals['_IMPORTPUBLICKEYRESPONSE']._serialized_start=865
  _globals['_IMPORTPUBLICKEYRESPONSE']._serialized_end=924
  _globals['_LISTKEYSFILTERS']._serialized_start=927
  _globals['_LISTKEYSFILTERS']._serialized_end=1072
  _globals['_LISTMYKEYSREQUEST']._serialized_start=1074
  _globals['_LISTMYKEYSREQUEST']._serialized_end=1178
  _globals['_LISTPUBLICKEYSREQUEST']._serialized_start=1180
  _globals['_LISTPUBLICKEYSREQUEST']._serialized_end=1288
  _globals['_PRIVATEKEYMETADATA']._serialized_start=1291
  _globals['_PRIVATEKEYMETADATA']._serialized_end=1453
  _globals['_LISTMYKEYSRESPONSE']._serialized_start=1456
  _globals['_LISTMYKEYSRESPONSE']._serialized_end=1590
  _globals['_LISTPUBLICKEYSRESPONSE']._serialized_start=1592
  _globals['_LISTPUBLICKEYSRESPONSE']._serialized_end=1704
  _globals['_GENERATESIGNINGKEYREQUEST']._serialized_start=1707
  _globals['_GENERATESIGNINGKEYREQUEST']._serialized_end=1839
  _globals['_GENERATESIGNINGKEYRESPONSE']._serialized_start=1841
  _globals['_GENERATESIGNINGKEYRESPONSE']._serialized_end=1954
  _globals['_GENERATEENCRYPTIONKEYREQUEST']._serialized_start=1957
  _globals['_GENERATEENCRYPTIONKEYREQUEST']._serialized_end=2089
  _globals['_GENERATEENCRYPTIONKEYRESPONSE']._serialized_start=2091
  _globals['_GENERATEENCRYPTIONKEYRESPONSE']._serialized_end=2210
  _globals['_REGISTERKMSSIGNINGKEYREQUEST']._serialized_start=2212
  _globals['_REGISTERKMSSIGNINGKEYREQUEST']._serialized_end=2292
  _globals['_REGISTERKMSSIGNINGKEYRESPONSE']._serialized_start=2294
  _globals['_REGISTERKMSSIGNINGKEYRESPONSE']._serialized_end=2410
  _globals['_REGISTERKMSENCRYPTIONKEYREQUEST']._serialized_start=2412
  _globals['_REGISTERKMSENCRYPTIONKEYREQUEST']._serialized_end=2495
  _globals['_REGISTERKMSENCRYPTIONKEYRESPONSE']._serialized_start=2497
  _globals['_REGISTERKMSENCRYPTIONKEYRESPONSE']._serialized_end=2619
  _globals['_ROTATEWRAPPERKEYREQUEST']._serialized_start=2621
  _globals['_ROTATEWRAPPERKEYREQUEST']._serialized_end=2691
  _globals['_ROTATEWRAPPERKEYRESPONSE']._serialized_start=2693
  _globals['_ROTATEWRAPPERKEYRESPONSE']._serialized_end=2719
  _globals['_GETWRAPPERKEYIDREQUEST']._serialized_start=2721
  _globals['_GETWRAPPERKEYIDREQUEST']._serialized_end=2745
  _globals['_GETWRAPPERKEYIDRESPONSE']._serialized_start=2747
  _globals['_GETWRAPPERKEYIDRESPONSE']._serialized_end=2810
  _globals['_EXPORTKEYPAIRREQUEST']._serialized_start=2812
  _globals['_EXPORTKEYPAIRREQUEST']._serialized_end=2939
  _globals['_EXPORTKEYPAIRRESPONSE']._serialized_start=2941
  _globals['_EXPORTKEYPAIRRESPONSE']._serialized_end=2991
  _globals['_IMPORTKEYPAIRREQUEST']._serialized_start=2993
  _globals['_IMPORTKEYPAIRREQUEST']._serialized_end=3090
  _globals['_IMPORTKEYPAIRRESPONSE']._serialized_start=3092
  _globals['_IMPORTKEYPAIRRESPONSE']._serialized_end=3115
  _globals['_DELETEKEYPAIRREQUEST']._serialized_start=3117
  _globals['_DELETEKEYPAIRREQUEST']._serialized_end=3173
  _globals['_DELETEKEYPAIRRESPONSE']._serialized_start=3175
  _globals['_DELETEKEYPAIRRESPONSE']._serialized_end=3198
  _globals['_VAULTSERVICE']._serialized_start=3201
  _globals['_VAULTSERVICE']._serialized_end=5090
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....protocol.v30 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v30 import traffic_control_parameters_pb2 as _traffic_control_parameters_pb2
from . import sequencer_initialization_snapshot_pb2 as _sequencer_initialization_snapshot_pb2
from ....topology.admin.v30 import topology_ext_pb2 as _topology_ext_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficControlStateRequest(_message.Message):
    __slots__ = ("members", "exact_timestamp", "relative_timestamp")
    class RelativeTimestamp(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        RELATIVE_TIMESTAMP_LATEST_SAFE_UNSPECIFIED: _ClassVar[TrafficControlStateRequest.RelativeTimestamp]
        RELATIVE_TIMESTAMP_LAST_UPDATE_PER_MEMBER: _ClassVar[TrafficControlStateRequest.RelativeTimestamp]
        RELATIVE_TIMESTAMP_LATEST_APPROXIMATE: _ClassVar[TrafficControlStateRequest.RelativeTimestamp]
    RELATIVE_TIMESTAMP_LATEST_SAFE_UNSPECIFIED: TrafficControlStateRequest.RelativeTimestamp
    RELATIVE_TIMESTAMP_LAST_UPDATE_PER_MEMBER: TrafficControlStateRequest.RelativeTimestamp
    RELATIVE_TIMESTAMP_LATEST_APPROXIMATE: TrafficControlStateRequest.RelativeTimestamp
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    EXACT_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    members: _containers.RepeatedScalarFieldContainer[str]
    exact_timestamp: int
    relative_timestamp: TrafficControlStateRequest.RelativeTimestamp
    def __init__(self, members: _Optional[_Iterable[str]] = ..., exact_timestamp: _Optional[int] = ..., relative_timestamp: _Optional[_Union[TrafficControlStateRequest.RelativeTimestamp, str]] = ...) -> None: ...

class TrafficControlStateResponse(_message.Message):
    __slots__ = ("traffic_states",)
    class TrafficStatesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _traffic_control_parameters_pb2.TrafficState
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_traffic_control_parameters_pb2.TrafficState, _Mapping]] = ...) -> None: ...
    TRAFFIC_STATES_FIELD_NUMBER: _ClassVar[int]
    traffic_states: _containers.MessageMap[str, _traffic_control_parameters_pb2.TrafficState]
    def __init__(self, traffic_states: _Optional[_Mapping[str, _traffic_control_parameters_pb2.TrafficState]] = ...) -> None: ...

class SetTrafficPurchasedRequest(_message.Message):
    __slots__ = ("member", "serial", "total_traffic_purchased")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TRAFFIC_PURCHASED_FIELD_NUMBER: _ClassVar[int]
    member: str
    serial: int
    total_traffic_purchased: int
    def __init__(self, member: _Optional[str] = ..., serial: _Optional[int] = ..., total_traffic_purchased: _Optional[int] = ...) -> None: ...

class SetTrafficPurchasedResponse(_message.Message):
    __slots__ = ("max_sequencing_timestamp",)
    MAX_SEQUENCING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    max_sequencing_timestamp: _timestamp_pb2.Timestamp
    def __init__(self, max_sequencing_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SnapshotRequest(_message.Message):
    __slots__ = ("timestamp",)
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SnapshotResponse(_message.Message):
    __slots__ = ("success", "failure", "versioned_success")
    class Success(_message.Message):
        __slots__ = ("state",)
        STATE_FIELD_NUMBER: _ClassVar[int]
        state: _sequencer_initialization_snapshot_pb2.SequencerSnapshot
        def __init__(self, state: _Optional[_Union[_sequencer_initialization_snapshot_pb2.SequencerSnapshot, _Mapping]] = ...) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("reason",)
        REASON_FIELD_NUMBER: _ClassVar[int]
        reason: str
        def __init__(self, reason: _Optional[str] = ...) -> None: ...
    class VersionedSuccess(_message.Message):
        __slots__ = ("snapshot",)
        SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
        snapshot: bytes
        def __init__(self, snapshot: _Optional[bytes] = ...) -> None: ...
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    VERSIONED_SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: SnapshotResponse.Success
    failure: SnapshotResponse.Failure
    versioned_success: SnapshotResponse.VersionedSuccess
    def __init__(self, success: _Optional[_Union[SnapshotResponse.Success, _Mapping]] = ..., failure: _Optional[_Union[SnapshotResponse.Failure, _Mapping]] = ..., versioned_success: _Optional[_Union[SnapshotResponse.VersionedSuccess, _Mapping]] = ...) -> None: ...

class OnboardingStateRequest(_message.Message):
    __slots__ = ("sequencer_uid", "timestamp")
    SEQUENCER_UID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    sequencer_uid: str
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, sequencer_uid: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class OnboardingStateResponse(_message.Message):
    __slots__ = ("onboarding_state_for_sequencer",)
    ONBOARDING_STATE_FOR_SEQUENCER_FIELD_NUMBER: _ClassVar[int]
    onboarding_state_for_sequencer: bytes
    def __init__(self, onboarding_state_for_sequencer: _Optional[bytes] = ...) -> None: ...

class OnboardingStateForSequencer(_message.Message):
    __slots__ = ("topology_snapshot", "static_domain_parameters", "sequencer_snapshot")
    TOPOLOGY_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    STATIC_DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
    topology_snapshot: _topology_ext_pb2.TopologyTransactions
    static_domain_parameters: _sequencing_pb2.StaticDomainParameters
    sequencer_snapshot: _sequencer_initialization_snapshot_pb2.SequencerSnapshot
    def __init__(self, topology_snapshot: _Optional[_Union[_topology_ext_pb2.TopologyTransactions, _Mapping]] = ..., static_domain_parameters: _Optional[_Union[_sequencing_pb2.StaticDomainParameters, _Mapping]] = ..., sequencer_snapshot: _Optional[_Union[_sequencer_initialization_snapshot_pb2.SequencerSnapshot, _Mapping]] = ...) -> None: ...

class PruningStatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PruningStatusResponse(_message.Message):
    __slots__ = ("pruning_status",)
    PRUNING_STATUS_FIELD_NUMBER: _ClassVar[int]
    pruning_status: _sequencer_initialization_snapshot_pb2.SequencerPruningStatus
    def __init__(self, pruning_status: _Optional[_Union[_sequencer_initialization_snapshot_pb2.SequencerPruningStatus, _Mapping]] = ...) -> None: ...

class DisableMemberRequest(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: str
    def __init__(self, member: _Optional[str] = ...) -> None: ...

class DisableMemberResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/health/admin/v0/status_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/health/admin/v0/status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<com/digitalasset/canton/health/admin/v0/status_service.proto\x12\'com.digitalasset.canton.health.admin.v0\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\"i\n\x13TopologyQueueStatus\x12\x18\n\x07manager\x18\x01 \x01(\rR\x07manager\x12\x1e\n\ndispatcher\x18\x02 \x01(\rR\ndispatcher\x12\x18\n\x07\x63lients\x18\x03 \x01(\rR\x07\x63lients\"\x8a\n\n\nNodeStatus\x12m\n\x0fnot_initialized\x18\x01 \x01(\x0b\x32\x42.com.digitalasset.canton.health.admin.v0.NodeStatus.NotInitializedH\x00R\x0enotInitialized\x12V\n\x07success\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.health.admin.v0.NodeStatus.StatusH\x00R\x07success\x1a\xdc\x03\n\x06Status\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12[\n\x05ports\x18\x03 \x03(\x0b\x32\x45.com.digitalasset.canton.health.admin.v0.NodeStatus.Status.PortsEntryR\x05ports\x12\x14\n\x05\x65xtra\x18\x04 \x01(\x0cR\x05\x65xtra\x12\x16\n\x06\x61\x63tive\x18\x05 \x01(\x08R\x06\x61\x63tive\x12\x65\n\x0ftopology_queues\x18\x06 \x01(\x0b\x32<.com.digitalasset.canton.health.admin.v0.TopologyQueueStatusR\x0etopologyQueues\x12\x63\n\ncomponents\x18\x07 \x03(\x0b\x32\x43.com.digitalasset.canton.health.admin.v0.NodeStatus.ComponentStatusR\ncomponents\x1a\x38\n\nPortsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\x1a\x9f\x04\n\x0f\x43omponentStatus\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12`\n\x02ok\x18\x02 \x01(\x0b\x32N.com.digitalasset.canton.health.admin.v0.NodeStatus.ComponentStatus.StatusDataH\x00R\x02ok\x12l\n\x08\x64\x65graded\x18\x03 \x01(\x0b\x32N.com.digitalasset.canton.health.admin.v0.NodeStatus.ComponentStatus.StatusDataH\x00R\x08\x64\x65graded\x12h\n\x06\x66\x61iled\x18\x04 \x01(\x0b\x32N.com.digitalasset.canton.health.admin.v0.NodeStatus.ComponentStatus.StatusDataH\x00R\x06\x66\x61iled\x12\x66\n\x05\x66\x61tal\x18\x05 \x01(\x0b\x32N.com.digitalasset.canton.health.admin.v0.NodeStatus.ComponentStatus.StatusDataH\x00R\x05\x66\x61tal\x1aL\n\nStatusData\x12>\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x65scriptionB\x08\n\x06status\x1a(\n\x0eNotInitialized\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tiveB\n\n\x08response\"O\n\x11HealthDumpRequest\x12:\n\tchunkSize\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\tchunkSize\"\'\n\x0fHealthDumpChunk\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xa7\x01\n\x10\x44omainStatusInfo\x12\x35\n\x16\x63onnected_participants\x18\x01 \x03(\tR\x15\x63onnectedParticipants\x12\\\n\tsequencer\x18\x02 \x01(\x0b\x32>.com.digitalasset.canton.health.admin.v0.SequencerHealthStatusR\tsequencer\"\xf1\x01\n\x15ParticipantStatusInfo\x12{\n\x11\x63onnected_domains\x18\x01 \x03(\x0b\x32N.com.digitalasset.canton.health.admin.v0.ParticipantStatusInfo.ConnectedDomainR\x10\x63onnectedDomains\x12\x16\n\x06\x61\x63tive\x18\x02 \x01(\x08R\x06\x61\x63tive\x1a\x43\n\x0f\x43onnectedDomain\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x18\n\x07healthy\x18\x02 \x01(\x08R\x07healthy\"\x9c\x02\n\x13SequencerNodeStatus\x12\x35\n\x16\x63onnected_participants\x18\x01 \x03(\tR\x15\x63onnectedParticipants\x12\\\n\tsequencer\x18\x02 \x01(\x0b\x32>.com.digitalasset.canton.health.admin.v0.SequencerHealthStatusR\tsequencer\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12S\n\x05\x61\x64min\x18\x04 \x01(\x0b\x32=.com.digitalasset.canton.health.admin.v0.SequencerAdminStatusR\x05\x61\x64min\"g\n\x15SequencerHealthStatus\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\x12\x36\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x64\x65tails\"J\n\x14SequencerAdminStatus\x12\x32\n\x15\x61\x63\x63\x65pts_admin_changes\x18\x01 \x01(\x08R\x13\x61\x63\x63\x65ptsAdminChanges\"1\n\x12MediatorNodeStatus\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\"*\n\x12SetLogLevelRequest\x12\x14\n\x05level\x18\x01 \x01(\tR\x05level\"\x15\n\x13SetLogLevelResponse\"\x16\n\x14GetLastErrorsRequest\"\xb3\x01\n\x15GetLastErrorsResponse\x12\\\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x44.com.digitalasset.canton.health.admin.v0.GetLastErrorsResponse.ErrorR\x06\x65rrors\x1a<\n\x05\x45rror\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"5\n\x18GetLastErrorTraceRequest\x12\x19\n\x08trace_id\x18\x01 \x01(\tR\x07traceId\"7\n\x19GetLastErrorTraceResponse\x12\x1a\n\x08messages\x18\x01 \x03(\tR\x08messages2\xa2\x05\n\rStatusService\x12U\n\x06Status\x12\x16.google.protobuf.Empty\x1a\x33.com.digitalasset.canton.health.admin.v0.NodeStatus\x12\x84\x01\n\nHealthDump\x12:.com.digitalasset.canton.health.admin.v0.HealthDumpRequest\x1a\x38.com.digitalasset.canton.health.admin.v0.HealthDumpChunk0\x01\x12\x88\x01\n\x0bSetLogLevel\x12;.com.digitalasset.canton.health.admin.v0.SetLogLevelRequest\x1a<.com.digitalasset.canton.health.admin.v0.SetLogLevelResponse\x12\x8e\x01\n\rGetLastErrors\x12=.com.digitalasset.canton.health.admin.v0.GetLastErrorsRequest\x1a>.com.digitalasset.canton.health.admin.v0.GetLastErrorsResponse\x12\x96\x01\n\rGetErrorTrace\x12\x41.com.digitalasset.canton.health.admin.v0.GetLastErrorTraceRequest\x1a\x42.com.digitalasset.canton.health.admin.v0.GetLastErrorTraceResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/health/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.health.admin.v0.status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/health/admin/v0'
  _globals['_NODESTATUS_STATUS_PORTSENTRY']._loaded_options = None
  _globals['_NODESTATUS_STATUS_PORTSENTRY']._serialized_options = b'8\001'
  _globals['_TOPOLOGYQUEUESTATUS']._serialized_start=198
  _globals['_TOPOLOGYQUEUESTATUS']._serialized_end=303
  _globals['_NODESTATUS']._serialized_start=306
  _globals['_NODESTATUS']._serialized_end=1596
  _globals['_NODESTATUS_STATUS']._serialized_start=520
  _globals['_NODESTATUS_STATUS']._serialized_end=996
  _globals['_NODESTATUS_STATUS_PORTSENTRY']._serialized_start=940
  _globals['_NODESTATUS_STATUS_PORTSENTRY']._serialized_end=996
  _globals['_NODESTATUS_COMPONENTSTATUS']._serialized_start=999
  _globals['_NODESTATUS_COMPONENTSTATUS']._serialized_end=1542
  _globals['_NODESTATUS_COMPONENTSTATUS_STATUSDATA']._serialized_start=1456
  _globals['_NODESTATUS_COMPONENTSTATUS_STATUSDATA']._serialized_end=1532
  _globals['_NODESTATUS_NOTINITIALIZED']._serialized_start=1544
  _globals['_NODESTATUS_NOTINITIALIZED']._serialized_end=1584
  _globals['_HEALTHDUMPREQUEST']._serialized_start=1598
  _globals['_HEALTHDUMPREQUEST']._serialized_end=1677
  _globals['_HEALTHDUMPCHUNK']._serialized_start=1679
  _globals['_HEALTHDUMPCHUNK']._serialized_end=1718
  _globals['_DOMAINSTATUSINFO']._serialized_start=1721
  _globals['_DOMAINSTATUSINFO']._serialized_end=1888
  _globals['_PARTICIPANTSTATUSINFO']._serialized_start=1891
  _globals['_PARTICIPANTSTATUSINFO']._serialized_end=2132
  _globals['_PARTICIPANTSTATUSINFO_CONNECTEDDOMAIN']._serialized_start=2065
  _globals['_PARTICIPANTSTATUSINFO_CONNECTEDDOMAIN']._serialized_end=2132
  _globals['_SEQUENCERNODESTATUS']._serialized_start=2135
  _globals['_SEQUENCERNODESTATUS']._serialized_end=2419
  _globals['_SEQUENCERHEALTHSTATUS']._serialized_start=2421
  _globals['_SEQUENCERHEALTHSTATUS']._serialized_end=2524
  _globals['_SEQUENCERADMINSTATUS']._serialized_start=2526
  _globals['_SEQUENCERADMINSTATUS']._serialized_end=2600
  _globals['_MEDIATORNODESTATUS']._serialized_start=2602
  _globals['_MEDIATORNODESTATUS']._serialized_end=2651
  _globals['_SETLOGLEVELREQUEST']._serialized_start=2653
  _globals['_SETLOGLEVELREQUEST']._serialized_end=2695
  _globals['_SETLOGLEVELRESPONSE']._serialized_start=2697
  _globals['_SETLOGLEVELRESPONSE']._serialized_end=2718
  _globals['_GETLASTERRORSREQUEST']._serialized_start=2720
  _globals['_GETLASTERRORSREQUEST']._serialized_end=2742
  _globals['_GETLASTERRORSRESPONSE']._serialized_start=2745
  _globals['_GETLASTERRORSRESPONSE']._serialized_end=2924
  _globals['_GETLASTERRORSRESPONSE_ERROR']._serialized_start=2864
  _globals['_GETLASTERRORSRESPONSE_ERROR']._serialized_end=2924
  _globals['_GETLASTERRORTRACEREQUEST']._serialized_start=2926
  _globals['_GETLASTERRORTRACEREQUEST']._serialized_end=2979
  _globals['_GETLASTERRORTRACERESPONSE']._serialized_start=2981
  _globals['_GETLASTERRORTRACERESPONSE']._serialized_end=3036
  _globals['_STATUSSERVICE']._serialized_start=3039
  _globals['_STATUSSERVICE']._serialized_end=3713
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .topology_aggregation_service_pb2 import ListKeyOwnersRequest, ListKeyOwnersResponse, ListPartiesRequest, ListPartiesResponse

__all__ = [
    "TopologyAggregationServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class TopologyAggregationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TopologyAggregationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TopologyAggregationServiceAsyncStub: ...  # type: ignore
    def ListParties(self, __1: ListPartiesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListPartiesResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartiesResponse]]: ...
    def ListKeyOwners(self, __1: ListKeyOwnersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListKeyOwnersResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListKeyOwnersResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyAggregationServiceBlockingStub(TopologyAggregationServiceStub):
    def ListParties(self, __1: ListPartiesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartiesResponse: ...
    def ListKeyOwners(self, __1: ListKeyOwnersRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListKeyOwnersResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyAggregationServiceAsyncStub(TopologyAggregationServiceStub):
    def ListParties(self, __1: ListPartiesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartiesResponse]: ...  # type: ignore
    def ListKeyOwners(self, __1: ListKeyOwnersRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListKeyOwnersResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import event_pb2 as _event_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetEventsByContractIdRequest(_message.Message):
    __slots__ = ("contract_id", "requesting_parties")
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    REQUESTING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    contract_id: str
    requesting_parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, contract_id: _Optional[str] = ..., requesting_parties: _Optional[_Iterable[str]] = ...) -> None: ...

class GetEventsByContractIdResponse(_message.Message):
    __slots__ = ("created", "archived")
    CREATED_FIELD_NUMBER: _ClassVar[int]
    ARCHIVED_FIELD_NUMBER: _ClassVar[int]
    created: Created
    archived: Archived
    def __init__(self, created: _Optional[_Union[Created, _Mapping]] = ..., archived: _Optional[_Union[Archived, _Mapping]] = ...) -> None: ...

class Created(_message.Message):
    __slots__ = ("created_event", "domain_id")
    CREATED_EVENT_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    created_event: _event_pb2.CreatedEvent
    domain_id: str
    def __init__(self, created_event: _Optional[_Union[_event_pb2.CreatedEvent, _Mapping]] = ..., domain_id: _Optional[str] = ...) -> None: ...

class Archived(_message.Message):
    __slots__ = ("archived_event", "domain_id")
    ARCHIVED_EVENT_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    archived_event: _event_pb2.ArchivedEvent
    domain_id: str
    def __init__(self, archived_event: _Optional[_Union[_event_pb2.ArchivedEvent, _Mapping]] = ..., domain_id: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import user_management_service_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/daml/ledger/api/v2/admin/user_management_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UserManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateUser = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/CreateUser',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.CreateUserResponse.FromString,
                _registered_method=True)
        self.GetUser = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/GetUser',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GetUserRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GetUserResponse.FromString,
                _registered_method=True)
        self.UpdateUser = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/UpdateUser',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserResponse.FromString,
                _registered_method=True)
        self.DeleteUser = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/DeleteUser',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.DeleteUserResponse.FromString,
                _registered_method=True)
        self.ListUsers = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/ListUsers',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUsersResponse.FromString,
                _registered_method=True)
        self.GrantUserRights = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/GrantUserRights',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GrantUserRightsRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GrantUserRightsResponse.FromString,
                _registered_method=True)
        self.RevokeUserRights = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/RevokeUserRights',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.RevokeUserRightsRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.RevokeUserRightsResponse.FromString,
                _registered_method=True)
        self.ListUserRights = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/ListUserRights',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUserRightsRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUserRightsResponse.FromString,
                _registered_method=True)
        self.UpdateUserIdentityProviderId = channel.unary_unary(
                '/com.daml.ledger.api.v2.admin.UserManagementService/UpdateUserIdentityProviderId',
                request_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserIdentityProviderIdRequest.SerializeToString,
                response_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserIdentityProviderIdResponse.FromString,
                _registered_method=True)


class UserManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GrantUserRights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeUserRights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserRights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserIdentityProviderId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.CreateUserRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.CreateUserResponse.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GetUserRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GetUserResponse.SerializeToString,
            ),
            'UpdateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUser,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserResponse.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.DeleteUserRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.DeleteUserResponse.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUsersRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUsersResponse.SerializeToString,
            ),
            'GrantUserRights': grpc.unary_unary_rpc_method_handler(
                    servicer.GrantUserRights,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GrantUserRightsRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GrantUserRightsResponse.SerializeToString,
            ),
            'RevokeUserRights': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeUserRights,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.RevokeUserRightsRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.RevokeUserRightsResponse.SerializeToString,
            ),
            'ListUserRights': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserRights,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUserRightsRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUserRightsResponse.SerializeToString,
            ),
            'UpdateUserIdentityProviderId': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserIdentityProviderId,
                    request_deserializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserIdentityProviderIdRequest.FromString,
                    response_serializer=com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserIdentityProviderIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.daml.ledger.api.v2.admin.UserManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.daml.ledger.api.v2.admin.UserManagementService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/CreateUser',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.CreateUserRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.CreateUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/GetUser',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GetUserRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GetUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/UpdateUser',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/DeleteUser',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.DeleteUserRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.DeleteUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/ListUsers',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUsersRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GrantUserRights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/GrantUserRights',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GrantUserRightsRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.GrantUserRightsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RevokeUserRights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/RevokeUserRights',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.RevokeUserRightsRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.RevokeUserRightsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListUserRights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/ListUserRights',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUserRightsRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.ListUserRightsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateUserIdentityProviderId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.daml.ledger.api.v2.admin.UserManagementService/UpdateUserIdentityProviderId',
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserIdentityProviderIdRequest.SerializeToString,
            com_dot_daml_dot_ledger_dot_api_dot_v2_dot_admin_dot_user__management__service__pb2.UpdateUserIdentityProviderIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencerConnectionValidation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN: _ClassVar[SequencerConnectionValidation]
    DISABLED: _ClassVar[SequencerConnectionValidation]
    ACTIVE: _ClassVar[SequencerConnectionValidation]
    ALL: _ClassVar[SequencerConnectionValidation]
UNKNOWN: SequencerConnectionValidation
DISABLED: SequencerConnectionValidation
ACTIVE: SequencerConnectionValidation
ALL: SequencerConnectionValidation

class SequencerConnection(_message.Message):
    __slots__ = ("grpc", "alias")
    class Grpc(_message.Message):
        __slots__ = ("connections", "transportSecurity", "customTrustCertificates")
        CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
        TRANSPORTSECURITY_FIELD_NUMBER: _ClassVar[int]
        CUSTOMTRUSTCERTIFICATES_FIELD_NUMBER: _ClassVar[int]
        connections: _containers.RepeatedScalarFieldContainer[str]
        transportSecurity: bool
        customTrustCertificates: _wrappers_pb2.BytesValue
        def __init__(self, connections: _Optional[_Iterable[str]] = ..., transportSecurity: bool = ..., customTrustCertificates: _Optional[_Union[_wrappers_pb2.BytesValue, _Mapping]] = ...) -> None: ...
    GRPC_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    grpc: SequencerConnection.Grpc
    alias: str
    def __init__(self, grpc: _Optional[_Union[SequencerConnection.Grpc, _Mapping]] = ..., alias: _Optional[str] = ...) -> None: ...

class SequencerConnections(_message.Message):
    __slots__ = ("sequencer_connections", "sequencerTrustThreshold", "submission_request_amplification")
    SEQUENCER_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCERTRUSTTHRESHOLD_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_REQUEST_AMPLIFICATION_FIELD_NUMBER: _ClassVar[int]
    sequencer_connections: _containers.RepeatedCompositeFieldContainer[SequencerConnection]
    sequencerTrustThreshold: int
    submission_request_amplification: SubmissionRequestAmplification
    def __init__(self, sequencer_connections: _Optional[_Iterable[_Union[SequencerConnection, _Mapping]]] = ..., sequencerTrustThreshold: _Optional[int] = ..., submission_request_amplification: _Optional[_Union[SubmissionRequestAmplification, _Mapping]] = ...) -> None: ...

class SubmissionRequestAmplification(_message.Message):
    __slots__ = ("factor", "patience")
    FACTOR_FIELD_NUMBER: _ClassVar[int]
    PATIENCE_FIELD_NUMBER: _ClassVar[int]
    factor: int
    patience: _duration_pb2.Duration
    def __init__(self, factor: _Optional[int] = ..., patience: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRcom/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x35\x63om/digitalasset/canton/protocol/v30/sequencing.proto\"\xc4\x01\n*InitializeSequencerFromGenesisStateRequest\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12i\n\x11\x64omain_parameters\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v30.StaticDomainParametersR\x10\x64omainParameters\"M\n+InitializeSequencerFromGenesisStateResponse\x12\x1e\n\nreplicated\x18\x01 \x01(\x08R\nreplicated\"Z\n-InitializeSequencerFromOnboardingStateRequest\x12)\n\x10onboarding_state\x18\x01 \x01(\x0cR\x0fonboardingState\"P\n.InitializeSequencerFromOnboardingStateResponse\x12\x1e\n\nreplicated\x18\x01 \x01(\x08R\nreplicated2\xe3\x03\n\x1eSequencerInitializationService\x12\xda\x01\n#InitializeSequencerFromGenesisState\x12W.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromGenesisStateRequest\x1aX.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromGenesisStateResponse(\x01\x12\xe3\x01\n&InitializeSequencerFromOnboardingState\x12Z.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromOnboardingStateRequest\x1a[.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromOnboardingStateResponse(\x01\x42\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATEREQUEST']._serialized_start=187
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATEREQUEST']._serialized_end=383
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATERESPONSE']._serialized_start=385
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATERESPONSE']._serialized_end=462
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATEREQUEST']._serialized_start=464
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATEREQUEST']._serialized_end=554
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATERESPONSE']._serialized_start=556
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATERESPONSE']._serialized_end=636
  _globals['_SEQUENCERINITIALIZATIONSERVICE']._serialized_start=639
  _globals['_SEQUENCERINITIALIZATIONSERVICE']._serialized_end=1122
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/admin/participant_pruning_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/admin/participant_pruning_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>com/daml/ledger/api/v1/admin/participant_pruning_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\"\x94\x01\n\x0cPruneRequest\x12\x1e\n\x0bprune_up_to\x18\x01 \x01(\tR\tpruneUpTo\x12#\n\rsubmission_id\x18\x02 \x01(\tR\x0csubmissionId\x12?\n\x1cprune_all_divulged_contracts\x18\x03 \x01(\x08R\x19pruneAllDivulgedContracts\"\x0f\n\rPruneResponse2}\n\x19ParticipantPruningService\x12`\n\x05Prune\x12*.com.daml.ledger.api.v1.admin.PruneRequest\x1a+.com.daml.ledger.api.v1.admin.PruneResponseB\xaf\x01\n\x1c\x63om.daml.ledger.api.v1.adminB#ParticipantPruningServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.admin.participant_pruning_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v1.adminB#ParticipantPruningServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin'
  _globals['_PRUNEREQUEST']._serialized_start=97
  _globals['_PRUNEREQUEST']._serialized_end=245
  _globals['_PRUNERESPONSE']._serialized_start=247
  _globals['_PRUNERESPONSE']._serialized_end=262
  _globals['_PARTICIPANTPRUNINGSERVICE']._serialized_start=264
  _globals['_PARTICIPANTPRUNINGSERVICE']._serialized_end=389
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v30 import crypto_pb2 as _crypto_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencerAuthentication(_message.Message):
    __slots__ = ()
    class ChallengeRequest(_message.Message):
        __slots__ = ("member", "member_protocol_versions")
        MEMBER_FIELD_NUMBER: _ClassVar[int]
        MEMBER_PROTOCOL_VERSIONS_FIELD_NUMBER: _ClassVar[int]
        member: str
        member_protocol_versions: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, member: _Optional[str] = ..., member_protocol_versions: _Optional[_Iterable[str]] = ...) -> None: ...
    class ChallengeResponse(_message.Message):
        __slots__ = ("success", "failure")
        class Success(_message.Message):
            __slots__ = ("domain_version", "nonce", "fingerprints")
            DOMAIN_VERSION_FIELD_NUMBER: _ClassVar[int]
            NONCE_FIELD_NUMBER: _ClassVar[int]
            FINGERPRINTS_FIELD_NUMBER: _ClassVar[int]
            domain_version: str
            nonce: bytes
            fingerprints: _containers.RepeatedScalarFieldContainer[str]
            def __init__(self, domain_version: _Optional[str] = ..., nonce: _Optional[bytes] = ..., fingerprints: _Optional[_Iterable[str]] = ...) -> None: ...
        class Failure(_message.Message):
            __slots__ = ("code", "reason")
            CODE_FIELD_NUMBER: _ClassVar[int]
            REASON_FIELD_NUMBER: _ClassVar[int]
            code: int
            reason: str
            def __init__(self, code: _Optional[int] = ..., reason: _Optional[str] = ...) -> None: ...
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        success: SequencerAuthentication.ChallengeResponse.Success
        failure: SequencerAuthentication.ChallengeResponse.Failure
        def __init__(self, success: _Optional[_Union[SequencerAuthentication.ChallengeResponse.Success, _Mapping]] = ..., failure: _Optional[_Union[SequencerAuthentication.ChallengeResponse.Failure, _Mapping]] = ...) -> None: ...
    class AuthenticateRequest(_message.Message):
        __slots__ = ("member", "signature", "nonce")
        MEMBER_FIELD_NUMBER: _ClassVar[int]
        SIGNATURE_FIELD_NUMBER: _ClassVar[int]
        NONCE_FIELD_NUMBER: _ClassVar[int]
        member: str
        signature: _crypto_pb2.Signature
        nonce: bytes
        def __init__(self, member: _Optional[str] = ..., signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., nonce: _Optional[bytes] = ...) -> None: ...
    class AuthenticateResponse(_message.Message):
        __slots__ = ("success", "failure")
        class Success(_message.Message):
            __slots__ = ("token", "expires_at")
            TOKEN_FIELD_NUMBER: _ClassVar[int]
            EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
            token: bytes
            expires_at: _timestamp_pb2.Timestamp
            def __init__(self, token: _Optional[bytes] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
        class Failure(_message.Message):
            __slots__ = ("code", "reason")
            CODE_FIELD_NUMBER: _ClassVar[int]
            REASON_FIELD_NUMBER: _ClassVar[int]
            code: int
            reason: str
            def __init__(self, code: _Optional[int] = ..., reason: _Optional[str] = ...) -> None: ...
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        success: SequencerAuthentication.AuthenticateResponse.Success
        failure: SequencerAuthentication.AuthenticateResponse.Failure
        def __init__(self, success: _Optional[_Union[SequencerAuthentication.AuthenticateResponse.Success, _Mapping]] = ..., failure: _Optional[_Union[SequencerAuthentication.AuthenticateResponse.Failure, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/daml_lf_2_1/daml_lf.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/daml_lf_2_1/daml_lf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import daml_lf2_pb2 as com_dot_daml_dot_daml__lf__2__1_dot_daml__lf2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"com/daml/daml_lf_2_1/daml_lf.proto\x12\x0b\x64\x61ml_lf_2_1\x1a#com/daml/daml_lf_2_1/daml_lf2.proto\"m\n\x0e\x41rchivePayload\x12\x14\n\x05minor\x18\x03 \x01(\tR\x05minor\x12\x30\n\tdaml_lf_2\x18\x04 \x01(\x0b\x32\x12.daml_lf_2.PackageH\x00R\x07\x64\x61mlLf2B\x05\n\x03SumJ\x06\x08\x8fN\x10\x90NJ\x04\x08\x01\x10\x02\"w\n\x07\x41rchive\x12>\n\rhash_function\x18\x01 \x01(\x0e\x32\x19.daml_lf_2_1.HashFunctionR\x0chashFunction\x12\x18\n\x07payload\x18\x03 \x01(\x0cR\x07payload\x12\x12\n\x04hash\x18\x04 \x01(\tR\x04hash*\x1a\n\x0cHashFunction\x12\n\n\x06SHA256\x10\x00\x42p\n\x14\x63om.daml.daml_lf_2_1Z:github.com/digital-asset/dazl-client/v8/go/api/daml_lf_2_1\xaa\x02\x1b\x43om.Daml.Daml_Lf_2_1.DamlLfb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.daml_lf_2_1.daml_lf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.daml.daml_lf_2_1Z:github.com/digital-asset/dazl-client/v8/go/api/daml_lf_2_1\252\002\033Com.Daml.Daml_Lf_2_1.DamlLf'
  _globals['_HASHFUNCTION']._serialized_start=320
  _globals['_HASHFUNCTION']._serialized_end=346
  _globals['_ARCHIVEPAYLOAD']._serialized_start=88
  _globals['_ARCHIVEPAYLOAD']._serialized_end=197
  _globals['_ARCHIVE']._serialized_start=199
  _globals['_ARCHIVE']._serialized_end=318
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import sequencer_initialization_snapshot_pb2 as _sequencer_initialization_snapshot_pb2
from ....pruning.admin.v0 import pruning_pb2 as _pruning_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EthereumAccount(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class LedgerIdentity(_message.Message):
    __slots__ = ("ethereum_account",)
    class AuthorizeRequest(_message.Message):
        __slots__ = ("identify",)
        IDENTIFY_FIELD_NUMBER: _ClassVar[int]
        identify: LedgerIdentity
        def __init__(self, identify: _Optional[_Union[LedgerIdentity, _Mapping]] = ...) -> None: ...
    class AuthorizeResponse(_message.Message):
        __slots__ = ("success", "failure")
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        success: LedgerIdentity.Success
        failure: LedgerIdentity.Failure
        def __init__(self, success: _Optional[_Union[LedgerIdentity.Success, _Mapping]] = ..., failure: _Optional[_Union[LedgerIdentity.Failure, _Mapping]] = ...) -> None: ...
    class Success(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("reason",)
        REASON_FIELD_NUMBER: _ClassVar[int]
        reason: str
        def __init__(self, reason: _Optional[str] = ...) -> None: ...
    ETHEREUM_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    ethereum_account: EthereumAccount
    def __init__(self, ethereum_account: _Optional[_Union[EthereumAccount, _Mapping]] = ...) -> None: ...

class Pruning(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("timestamp",)
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        timestamp: _timestamp_pb2.Timestamp
        def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("details",)
        DETAILS_FIELD_NUMBER: _ClassVar[int]
        details: str
        def __init__(self, details: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class Snapshot(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("timestamp",)
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        timestamp: _timestamp_pb2.Timestamp
        def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("success", "failure", "versionedSuccess")
        SUCCESS_FIELD_NUMBER: _ClassVar[int]
        FAILURE_FIELD_NUMBER: _ClassVar[int]
        VERSIONEDSUCCESS_FIELD_NUMBER: _ClassVar[int]
        success: Snapshot.Success
        failure: Snapshot.Failure
        versionedSuccess: Snapshot.VersionedSuccess
        def __init__(self, success: _Optional[_Union[Snapshot.Success, _Mapping]] = ..., failure: _Optional[_Union[Snapshot.Failure, _Mapping]] = ..., versionedSuccess: _Optional[_Union[Snapshot.VersionedSuccess, _Mapping]] = ...) -> None: ...
    class Success(_message.Message):
        __slots__ = ("state",)
        STATE_FIELD_NUMBER: _ClassVar[int]
        state: _sequencer_initialization_snapshot_pb2.SequencerSnapshot
        def __init__(self, state: _Optional[_Union[_sequencer_initialization_snapshot_pb2.SequencerSnapshot, _Mapping]] = ...) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("reason",)
        REASON_FIELD_NUMBER: _ClassVar[int]
        reason: str
        def __init__(self, reason: _Optional[str] = ...) -> None: ...
    class VersionedSuccess(_message.Message):
        __slots__ = ("snapshot",)
        SNAPSHOT_FIELD_NUMBER: _ClassVar[int]
        snapshot: bytes
        def __init__(self, snapshot: _Optional[bytes] = ...) -> None: ...
    def __init__(self) -> None: ...

class DisableMemberRequest(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: str
    def __init__(self, member: _Optional[str] = ...) -> None: ...
